Page 81 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 81

Home

    And upon her forehead was a name written,
    MYSTERY, BABYLON THE GREAT, THE
    MOTHER OF HARLOTS AND ABOMINATIONS OF

    THE

    And the angel said unto me, Wherefore didst thou
    marvel? I will tell thee the mystery of the woman, . . .
    Revelation 17:7

    Although many events pictured in the book of
    Revelation are veiled in mystery, the veil of mystery is
    lifted from Mystery Babylon. The Apostle John records
    that after seeing a vision of an outwardly beautiful
    woman identified as Mystery, Babylon The Great, he is
    then told that the mystery of the woman will be
    explained. This explanation then follows, beginning with
    Revelation 1718 and continuing for the next twenty-six
    verses. These verses describe the power, wealth,
    character, and deeds of the men who make up Babylon.

    Babylon's seat of power is described as a "great city"
    six times. It is not described as a nation or kingdom but
    as, "that great city, which reigneth over the kings of the

    verses.

    earth."

    76

    Chapter 9

    Mystery Babylon Unveiled

    BABYLON

    THE EARTH.

    Revelation 17:5

    These verses